@@ -8,7 +8,8 @@ from feeluown.excs import NoUserLoggedIn, MediaNotFound
 from feeluown.library import AbstractProvider, ProviderV2, ProviderFlags as Pf, UserModel, VideoModel, \
     BriefPlaylistModel, BriefSongModel, LyricModel, SupportsSongSimilar, BriefSongProtocol, SupportsSongHotComments, \
     SupportsAlbumGet, BriefAlbumModel, SupportsPlaylistAddSong, SupportsPlaylistRemoveSong, BriefUserModel, \
-    BriefArtistModel, SearchType as FuoSearchType, ModelType, SimpleSearchResult, ModelNotFound
+    BriefArtistModel, SearchType as FuoSearchType, ModelType, SimpleSearchResult, ModelNotFound, Collection, \
+    CollectionType
 from feeluown.media import Quality, Media, MediaType, VideoAudioManifest
 from feeluown.utils.reader import SequentialReader
 
@@ -430,6 +431,18 @@ class BilibiliProvider(AbstractProvider, ProviderV2, SupportsSongSimilar, Suppor
             name=user.uname,
         ) for user in resp.data.list]
 
+    def current_user_list_playlists(self):
+        p1 = self.special_playlists()
+        p2 = self.user_playlists(self.get_current_user().identifier)
+        p3 = self.audio_favorite_playlists()
+        p4 = self.audio_collected_playlists()
+        return p1 + p2 + p3 + p4
+
+    def current_user_fav_create_playlists_rd(self):
+        p1 = self.fav_playlists(self.get_current_user().identifier)
+        p2 = self.audio_collected_playlists()
+        return p1 + p2
+
     def audio_favorite_playlists(self) -> List[BriefPlaylistModel]:
         resp = self._api.audio_favorite_list(PaginatedRequest(ps=100, pn=1))
         return BPlaylistModel.create_audio_model_list(resp)
@@ -622,6 +635,18 @@ class BilibiliProvider(AbstractProvider, ProviderV2, SupportsSongSimilar, Suppor
 
         return SequentialReader(g(), total)
 
+    def rec_a_collection_of_videos(self):
+        if self.has_current_user():
+            resp = self._api.home_recommend_videos(HomeRecommendVideosRequest(ps=12))
+            videos = [BVideoModel.create_recommend_video_model(v) for v in resp.data.item]
+        else:
+            videos = []
+        return Collection(
+            name='推荐视频',
+            type_=CollectionType.only_videos,
+            models=videos,
+        )
+
     @property
     def identifier(self):
         return __identifier__
